Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrCmdRun is returned when an error occurs during CLI command execution ErrCmdRun = errors.New("command execution error") // ErrGracefulShutdown is returned when graceful shutdown of the application cannot finish cleanly due to timeout or another signal ErrGracefulShutdown = errors.New("graceful shutdown error") )
Functions ¶
func RootCommandProvider ¶ added in v3.14.0
func RootCommandProvider( commands []*cobra.Command, eventRouterProvider eventRouterProvider, logger flamingo.Logger, flagSetProvider flagSetProvider, config *struct { Name string `inject:"config:flamingo.cmd.name"` }, ) *cobra.Command
RootCommandProvider configures root cobra command to be used by the framework
Types ¶
Click to show internal directories.
Click to hide internal directories.